pub enum LookupError {
InvalidHostTarget(ParseError),
ConnectionFailed(Error),
ErrorResponse(Error),
InvalidResponse(Error),
NotPocketRelay,
ServerOutdated(Version, Version),
}Expand description
Errors that can occur while looking up a server
Variants
InvalidHostTarget(ParseError)
The server url was invalid
ConnectionFailed(Error)
The server connection failed
ErrorResponse(Error)
The server gave an invalid response likely not a PR server
InvalidResponse(Error)
The server gave an invalid response likely not a PR server
NotPocketRelay
Server wasn’t a valid pocket relay server
ServerOutdated(Version, Version)
Server version is too old