pub struct LookupData {
pub url: Url,
pub version: Version,
pub association: Option<String>,
pub tunnel_port: Option<u16>,
}Expand description
Data from completing a lookup contains the resolved address from the connection to the server as well as the server version obtained from the server
Fields
url: UrlServer url
version: VersionThe server version
association: Option<String>Association token if the server supports providing one
tunnel_port: Option<u16>Tunnel port if the server provides one