Frame

Struct Frame 

pub struct Frame {
    pub header: FrameHeader,
    pub contents: Bytes,
}
Packet framing structure

Fields

header: FrameHeader

Header for the frame

contents: Bytes

The encoded byte contents of the packet

Implementations

Source

impl Frame

pub fn response_raw(header: &FrameHeader, contents: Bytes) -> Frame

Creates a new response frame responding to the provided header with the bytes contents of value

Arguments
  • header - The header of the frame to respond to
  • contents - The bytes of the frame
pub fn response<V>(header: &FrameHeader, value: V) -> Frame
where V: TdfSerialize,

Creates a new response frame responding to the provided header with the encoded contents of the value

Arguments
  • header - The header of the frame to respond to
  • value - The value to encode as the frame bytes
pub fn response_empty(header: &FrameHeader) -> Frame

Creates a new response frame responding to the provided header with empty contents

Arguments
  • header - The header of the frame to respond to