pub fn spawn_server_task<F>(task: F)where F: Future<Output = ()> + Send + 'static,
Spawns a server related task future onto the tokio runtime and adds the abort handle for the task to the task collection
task